==> openafs-1.5.68-src.tar.bz2: openafs-1.5.68/src/WINNT/netidmgr_plugin/langres.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by C:\work\openafs-git\src\Winnt\netidmgr_plugin\lang\en_us\langres.rc
//
#define IDS_AFS_SHORT_DESC              101
#define IDS_AFS_LONG_DESC               102
#define IDI_ICON1                       102
#define IDD_NC_AFS                      103
#define IDS_AFS_NAME                    103
#define IDS_NCAFS_COL_CELL              104
#define IDD_CFG_IDS_TAB                 104
#define IDS_NCAFS_COL_REALM             105
#define IDD_CFG_ID_TAB                  105
#define IDS_NCAFS_COL_METHOD            106
#define IDD_CFG_AFS                     106
#define IDS_NC_METHOD_AUTO              107
#define IDI_AFSTOKEN                    107
#define IDS_NC_METHOD_KRB5              108
#define IDI_AFSPLUGIN                   108
#define IDS_NC_METHOD_KRB4              109
#define IDI_NC_NEW                      109
#define IDS_NC_METHOD_KRB524            110
#define IDI_NC_EXIST                    110
#define IDS_NC_REALM_AUTO               111
#define IDI_NC_NOTOWNED                 111
#define IDS_NC_TT_NO_CELL               112
#define IDI_CRED_BROKEN                 112
#define IDS_NC_TT_CANT_ADD              113
#define IDI_CRED_NONE                   113
#define IDS_NC_TT_MALFORMED_CELL        114
#define IDI_CRED_OK                     114
#define IDS_NC_TT_NO_REALM              115
#define IDI_CRED_SVCSTOP                115
#define IDS_NC_AUTO                     116
#define IDS_NC_TT_MALFORMED_REALM       117
#define IDS_NC_TT_CANT_UPDATE           118
#define IDS_AFS_CREDTEXT_DIS            119
#define IDS_AFS_CREDTEXT_0              120
#define IDS_AFS_CREDTEXT_1              121
#define IDS_AFS_CREDTEXT_N              122
#define IDS_ATTR_CELL_SHORT_DESC        123
#define IDS_ATTR_REALM_SHORT_DESC       124
#define IDS_ATTR_METHOD_SHORT_DESC      125
#define IDS_ATTR_CLIENT_SHORT_DESC      126
#define IDS_ATTR_CLIENT_PRINC_SHORT_DESC 127
#define IDS_ATTR_SERVER_PRINC_SHORT_DESC 128
#define IDS_DEF_LOCATION                129
#define IDS_PLUGIN_DESC                 130
#define IDS_CFG_IDS_TAB                 131
#define IDS_CFG_ID_TAB                  132
#define IDS_CFG_MAIN_LONG               133
#define IDS_CFG_MAIN_SHORT              134
#define IDS_CFG_SVCSTATUS               135
#define IDS_NC_METHODL_AUTO             136
#define IDS_NC_METHODL_KRB5             137
#define IDS_NC_METHODL_KRB4             138
#define IDS_NC_METHODL_KRB524           139
#define IDS_NC_METHOD_INVALID           140
#define IDS_NC_TT_CONFLICT              141
#define IDS_NC_TT_PROBLEM               142
#define IDS_NC_TT_CONFLICTM             143
#define IDS_NC_TT_DETAILS               144
#define IDS_NC_TT_CONFLICTD             145
#define IDS_NC_TT_EXPIRED               146
#define IDS_NC_TT_EXISTS                147
#define IDS_NC_TT_NEW                   148
#define IDS_CFG_CANTSTART               149
#define IDS_CFG_CANTSTOP                150
#define IDS_ERR_CELLCONFIG              151
#define IDS_ERR_NOSERVICE               152
#define IDS_ERR_CELLCONFIG_S            153
#define IDS_ERR_GENERAL                 154
#define IDS_ACTION_AFS_HELP             155
#define IDS_ACTION_AFS_HELP_TT          156
#define IDS_CRED_TT_NONE                157
#define IDS_CRED_TT_TOK                 158
#define IDS_CRED_TT_NOS                 159
#define IDS_CRED_TT_SERR                160
#define IDC_NCAFS_OBTAIN                1001
#define IDC_NCAFS_TOKENLIST             1002
#define IDC_NCAFS_CELL                  1004
#define IDC_NCAFS_REALM                 1005
#define IDC_NCAFS_METHOD                1006
#define IDC_NCAFS_ADD_TOKEN             1007
#define IDC_NCAFS_DELETE_TOKEN          1008
#define IDC_CFG_SVCGRP                  1009
#define IDC_CFG_LBL_STATUS              1010
#define IDC_CFG_STATUS                  1011
#define IDC_CFG_LBL_VERSION             1012
#define IDC_CFG_VERSION                 1013
#define IDC_CFG_STOP                    1014
#define IDC_CFG_START                   1015
#define IDC_CFG_CPL                     1016
#define IDC_CFG_OBTAIN                  1017
#define IDC_CFG_PROGRESS                1019
#define IDC_CFG_LBL_COMPANY             1020
#define IDC_CFG_COMPANY                 1021
#define IDC_CFG_STARTGRP                1022
#define IDC_CHECK1                      1023
#define IDC_CFG_STARTAFSCREDS           1023

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        116
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         1024
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> openafs-1.8.13-src.tar.bz2: openafs-1.8.13/src/WINNT/netidmgr_plugin/langres.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by C:\work\openafs-git\src\Winnt\netidmgr_plugin\lang\en_us\langres.rc
//
#define IDS_AFS_SHORT_DESC              101
#define IDS_AFS_LONG_DESC               102
#define IDD_NC_AFS                      103
#define IDS_AFS_NAME                    103
#define IDS_NCAFS_COL_CELL              104
#define IDD_CFG_IDS_TAB                 104
#define IDS_NCAFS_COL_REALM             105
#define IDD_CFG_ID_TAB                  105
#define IDS_NCAFS_COL_METHOD            106
#define IDD_CFG_AFS                     106
#define IDS_NC_METHOD_AUTO              107
#define IDI_AFSTOKEN                    107
#define IDS_NC_METHOD_KRB5              108
#define IDI_AFSPLUGIN                   108
#define IDS_NC_METHOD_KRB4              109
#define IDI_NC_NEW                      109
#define IDS_NC_METHOD_KRB524            110
#define IDI_NC_EXIST                    110
#define IDS_NC_REALM_AUTO               111
#define IDI_NC_NOTOWNED                 111
#define IDS_NC_TT_NO_CELL               112
#define IDI_CRED_BROKEN                 112
#define IDS_NC_TT_CANT_ADD              113
#define IDI_CRED_NONE                   113
#define IDS_NC_TT_MALFORMED_CELL        114
#define IDI_CRED_OK                     114
#define IDS_NC_TT_NO_REALM              115
#define IDI_CRED_SVCSTOP                115
#define IDS_NC_AUTO                     116
#define IDS_NC_TT_MALFORMED_REALM       117
#define IDR_CTXMENU                     117
#define IDS_NC_TT_CANT_UPDATE           118
#define IDS_AFS_CREDTEXT_DIS            119
#define IDS_AFS_CREDTEXT_0              120
#define IDS_AFS_CREDTEXT_1              121
#define IDS_AFS_CREDTEXT_N              122
#define IDS_ATTR_CELL_SHORT_DESC        123
#define IDS_ATTR_REALM_SHORT_DESC       124
#define IDS_ATTR_METHOD_SHORT_DESC      125
#define IDS_ATTR_CLIENT_SHORT_DESC      126
#define IDS_ATTR_CLIENT_PRINC_SHORT_DESC 127
#define IDS_ATTR_SERVER_PRINC_SHORT_DESC 128
#define IDS_DEF_LOCATION                129
#define IDS_PLUGIN_DESC                 130
#define IDS_CFG_IDS_TAB                 131
#define IDS_CFG_ID_TAB                  132
#define IDS_CFG_MAIN_LONG               133
#define IDS_CFG_MAIN_SHORT              134
#define IDS_CFG_SVCSTATUS               135
#define IDS_NC_METHODL_AUTO             136
#define IDS_NC_METHODL_KRB5             137
#define IDS_NC_METHODL_KRB4             138
#define IDS_NC_METHODL_KRB524           139
#define IDS_NC_METHOD_INVALID           140
#define IDS_NC_TT_CONFLICT              141
#define IDS_NC_TT_PROBLEM               142
#define IDS_NC_TT_CONFLICTM             143
#define IDS_NC_TT_DETAILS               144
#define IDS_NC_TT_CONFLICTD             145
#define IDS_NC_TT_EXPIRED               146
#define IDS_NC_TT_EXISTS                147
#define IDS_NC_TT_NEW                   148
#define IDS_CFG_CANTSTART               149
#define IDS_CFG_CANTSTOP                150
#define IDS_ERR_CELLCONFIG              151
#define IDS_ERR_NOSERVICE               152
#define IDS_ERR_CELLCONFIG_S            153
#define IDS_ERR_GENERAL                 154
#define IDS_ACTION_AFS_HELP             155
#define IDS_ACTION_AFS_HELP_TT          156
#define IDS_CRED_TT_NONE                157
#define IDS_CRED_TT_TOK                 158
#define IDS_CRED_TT_NOS                 159
#define IDS_CRED_TT_SERR                160
#define IDS_ACT_OPEN                    161
#define IDS_ACT_NEW                     162
#define IDC_NCAFS_OBTAIN                1001
#define IDC_NCAFS_TOKENLIST             1002
#define IDC_NCAFS_CELL                  1004
#define IDC_NCAFS_REALM                 1005
#define IDC_NCAFS_METHOD                1006
#define IDC_NCAFS_ADD_TOKEN             1007
#define IDC_NCAFS_DELETE_TOKEN          1008
#define IDC_CFG_SVCGRP                  1009
#define IDC_CFG_LBL_STATUS              1010
#define IDC_CFG_STATUS                  1011
#define IDC_CFG_LBL_VERSION             1012
#define IDC_CFG_VERSION                 1013
#define IDC_CFG_STOP                    1014
#define IDC_CFG_START                   1015
#define IDC_CFG_CPL                     1016
#define IDC_CFG_OBTAIN                  1017
#define IDC_CFG_PROGRESS                1019
#define IDC_CFG_LBL_COMPANY             1020
#define IDC_CFG_COMPANY                 1021
#define IDC_CFG_STARTGRP                1022
#define IDC_CFG_STARTAFSCREDS           1023
#define ID_DEFAULT                      40003
#define ID_DUMMYPOPUP_OPENNETWORKIDENTITYMANAGER 40022
#define ID_DUMMYPOPUP_GETNEWCREDENTIALS 40023
#define ID_DUMMYPOPUP_                  40024
#define ID_DUMMYPOPUP_PRINCIPAL         40025
#define ID_DUMMYPOPUP_HELP              40026
#define ID_DUMMYPOPUP_ABOUTTHEOPENAFSPLUG 40027
#define ID_NEWCREDENTIALS               40028
#define ID_NOTOKENS                     40029
#define ID_TOKEN                        40030
#define ID_ABOUT                        40031
#define ID_SHOWHELP                     40032
#define ID_DUMMYPOPUP_OPENAFSRELEASENOTES 40033
#define ID_Menu                         40034
#define ID_Menu40035                    40035
#define ID_DUMMYPOPUP_40036             40036
#define ID_DISCARDTOKENS_DUMMYTOKEN     40037
#define ID_RELEASENOTES                 40038

// Next default values for new objects
//
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        118
#define _APS_NEXT_COMMAND_VALUE         40039
#define _APS_NEXT_CONTROL_VALUE         1024
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
